searchNodes=[{"doc":"MockMe is a simple mock server used to mock out your third party services in your tests. Unlike many mocking solutions, MockMe starts a real HTTP server and serves real static responses which may be toggled easily using the MockMe.set_response(:test, :result) function in your tests.Under the hood this package uses Plug.Router to manage the routes and Plug.Cowboy for the HTTP server. The path in the routes can be any valid path accepted by Plug.Router. See the Plug.Router docs or examples for more information.PhilosophyMost applications today obtain data from external sources using TCP. Typically, when integrating with these sources you have a few options when writing tests:Not test the code which calls out to these services. Not an option in my opinion, but all too often this is the chosen path.Short circuit the code paths before reaching out to the external service using some type of function overwrite mechanism in your tests. While better than not testing, this path often leaves you with untested code paths which could become issues or throw errors later. It also leaves you in a place where your tests do not acurrately document your code.Use something like VCR which will make an initial request to the live third party service the first time and then playback that recorded response on subsequent requests. This is a valid strategy, but I've always found it cumbersome to setup and manage. I also like to know exactly what is being returned in requests.Set up your own mock server which will respond to real HTTP requests and thus test your entire code path just like it would perform in production.Of all the options I prefer the last and it's what I do in all my Elixir projects. If you do it from scratch, it's only 2 files and takes very little effort. However, I got tired of setting it up in all my projects so I built an abstration with simple configuration that will build the server and run it for you in your tests.This project is built based on my own personal use. I'm certain there are other use cases and options which you may want to build into it. If you would like to contribute, please head over to the GitHub Repo and request access to make pull requests. I hope you find this project as useful as I have.SetupThe only things you need to do are:add {:mock_me, &quot;~&gt; 0.1.0&quot;} to your dependencies you mix.exsconfigure your code to point to the mock server url http://localhost:&lt;port (9081)&gt;configure your routes in your test/test_helper.exs filestart the MockMe server in your /test/test_help.exs fileuse MockMe in your testsConfig config/test.exs config :mock_me, port: 9081 This is only used if you want to change the port the mock server listens to. The default port is 9081.Dependencies Add :mock_me to your project dependencies. mix.exs def deps do [ {:mock_me, &quot;~&gt; 0.1.0&quot;} ] endInitilization test/test_helpers.ex ExUnit.start() MockMe.start() routes = [ %MockMe.Route{ name: :swapi_people, path: &quot;/swapi/people/:id&quot;, responses: [ %MockMe.Response{ flag: :success, body: MockMePhoenixExample.Test.Mocks.SWAPI.people(:success) }, %MockMe.Response{flag: :not_found, body: &quot;people-failure&quot;, status_code: 404} ] }, %MockMe.Route{ name: :swapi_starships, path: &quot;/swapi/starships/:id&quot;, responses: [ %MockMe.Response{ flag: :success, body: MockMePhoenixExample.Test.Mocks.SWAPI.starships(:success) }, %MockMe.Response{flag: :not_found, body: &quot;starships-failure&quot;, status_code: 404} ] } ] MockMe.add_routes(routes) MockMe.start_server()Use test/mock_me_phoenix_example/services/starwars.exs defmodule MockMePhoenixExample.Services.StarWarsTest do use ExUnit.Case alias MockMePhoenixExample.Services.StarWars # setup_all %{} do # # re-initializes the test case state # MockMe.reset_flags() # end test &quot;people/1 returns success&quot; do MockMe.set_response(:swapi_people, :success) assert {:ok, _} = StarWars.people(1) end test &quot;people/1 returns not found&quot; do MockMe.set_response(:swapi_people, :not_found) assert {:not_found, _} = StarWars.people(1) end test &quot;starships/1 returns success&quot; do MockMe.set_response(:swapi_starships, :success) assert {:ok, _} = StarWars.starships(1) end test &quot;starships/1 returns not found&quot; do MockMe.set_response(:swapi_starships, :not_found) assert {:not_found, _} = StarWars.starships(1) end end","ref":"MockMe.html","title":"MockMe","type":"module"},{"doc":"Add routes to your server. This goes in your test/test_helper.exs file.Defined routes using the MockMe.Route struct.The first response in the list of responses is considered the default response and will be used in the case where you haven't set a flag in your tests or when reset_flags/0 is called.Exampletest/test_helper.exsroute = %Route{ name: :test_me, path: &quot;/jwt&quot;, responses: [ %Response{flag: :success, body: &quot;some-body&quot;} ] } MockMe.start() MockMe.add_routes([route]) MockMe.start_server()","ref":"MockMe.html#add_routes/1","title":"MockMe.add_routes/1","type":"function"},{"doc":"Called inside each endoint to determine which response to return. You should never need to call this in your code except in the case of troubleshooting.","ref":"MockMe.html#flag_value/1","title":"MockMe.flag_value/1","type":"function"},{"doc":"A convienience function to view the state of the mocks. Primarily used for troubleshooting. You shouldn't need this in any of your tests.","ref":"MockMe.html#get_state/0","title":"MockMe.get_state/0","type":"function"},{"doc":"Used to reset the test state to the config defaults once tests in a module have been performed or before tests are run.Use this in the setup block of your tests or inside a test which you need to be sure uses the defaults.setup do MockMe.reset_flags() end","ref":"MockMe.html#reset_flags/0","title":"MockMe.reset_flags/0","type":"function"},{"doc":"Used to get the defined routes from state.","ref":"MockMe.html#routes/0","title":"MockMe.routes/0","type":"function"},{"doc":"The primary function in your tests. Call this to toggle responses from the mock server.To use this in your tests you can call:MockMe.set_response(:route_name, :route_flag)The response with the defined :flag will be returned when the endpoint is called.","ref":"MockMe.html#set_response/2","title":"MockMe.set_response/2","type":"function"},{"doc":"Start the application state in the unit tests. This prepares the state to accept the configuration for your mocked routes. To add routes use the MockMe.add_routes/1 functions.","ref":"MockMe.html#start/0","title":"MockMe.start/0","type":"function"},{"doc":"Used to start the mock server after routes have been added to state using add_routes/1","ref":"MockMe.html#start_server/0","title":"MockMe.start_server/0","type":"function"},{"doc":"Used to define how the mocked endpoint should respond.Example %Response{ flag: :success, #required body: &quot;some-serialized-body&quot;, #required status_code: 200 #default }","ref":"MockMe.Response.html","title":"MockMe.Response","type":"module"},{"doc":"Used to handle the toggling of the responses based on the route flag.","ref":"MockMe.ResponsePlug.html","title":"MockMe.ResponsePlug","type":"module"},{"doc":"","ref":"MockMe.ResponsePlug.html#call/2","title":"MockMe.ResponsePlug.call/2","type":"function"},{"doc":"","ref":"MockMe.ResponsePlug.html#init/1","title":"MockMe.ResponsePlug.init/1","type":"function"},{"doc":"A struct for defining routes and their test casesExample %Route{ name: :my_test_case, #required path: &quot;/my/test/case&quot;, #required method: :get, # default content-type: &quot;application/json&quot;, #default responses: [], #default } name: must be an atom which you use to identify this route in your tests path: must be a valid http url - usually the route for the api you're mocking method: may be either a single atom or a list of atoms - valid atoms are :get, :post, :put, :patch, :delete and :options content-type: must be a valid http response type, this is the content-type header for the response responses: must be an empty list or a list of %MockMe.Response{}","ref":"MockMe.Route.html","title":"MockMe.Route","type":"module"},{"doc":"Used to keep track of state for mocks in tests. Holds a map of route names and response flags which the server uses to determine which response to serve.Example%{ routes: [ %MockMe.Route{ name: :test_me, path: &quot;/test-path&quot;, responses: [ %MockMe.Response{flag: :success, body: &quot;test-body&quot;}, %MockMe.Response{flag: :failure, body: &quot;test-failure-body&quot;} ] } ], cases: %{ test_me: :success } }These values are populated from MockMe.add_routes/1 and then toggled using MockMe.set_response(:route_name, :route_flag).","ref":"MockMe.State.html","title":"MockMe.State","type":"module"},{"doc":"","ref":"MockMe.State.html#child_spec/1","title":"MockMe.State.child_spec/1","type":"function"},{"doc":"","ref":"MockMe.State.html#start_link/1","title":"MockMe.State.start_link/1","type":"function"}]